from .validate import validate as _validate


def extract(citizen_id: str) -> dict[str, str]:
    if (_validate(citizen_id) == False):
        raise ValueError("Citizen ID is not valid")

    person_type = __person_type(citizen_id)
    born_address = __born_address(citizen_id)
    first_order = __first_order(citizen_id)
    second_order = __second_order(citizen_id)
    return {
        'person_type': person_type,
        'born_address': born_address,
        'first_order': first_order,
        'second_order': second_order
    }


def __person_type(citizen_id: str) -> str:
    # Extract person type from first digit in citizen id
    data_dict = {
        '1': 'คนที่เกิดและมีสัญชาติไทยและได้แจ้งเกิดภายในกำหนดเวลา',
        '2': 'คนที่เกิดและมีสัญชาติไทยได้แจ้งเกิดเกินกำหนดเวลา',
        '3': 'คนไทยและคนต่างด้าวที่มีใบสำคัญประจำตัวคนต่างด้าวและมีชื่ออยู่ในทะเบียนบ้านในสมัยเริ่มแรก',
        '4': 'คนไทยและคนต่างด้าวที่มีใบสำคัญคนต่างด้าว แต่แจ้งย้ายเข้าโดยยังไม่มีเลขประจำตัวประชาชนในสมัยเริ่มแรก',
        '5': 'คนไทยที่ได้รับอนุมัติให้เพิ่มชื่อเข้าไปในทะเบียนบ้านในกรณีตกสำรวจหรือกรณีอื่น ๆ',
        '6': 'ผู้ที่เข้าเมืองโดยไม่ชอบด้วยกฎหมาย และผู้ที่เข้าเมืองโดยชอบด้วยกฎหมายแต่อยู่ในลักษณะชั่วคราว',
        '7': 'บุตรของบุคคลประเภทที่ 6 ซึ่งเกิดในประเทศไทย',
        '8': 'คนต่างด้าวที่เข้าเมืองโดยถูกต้องตามกฎหมาย',
        '9': 'บุคคลที่ไม่มีสถานะทางทะเบียนราษฎร ไม่มีสัญชาติและยังไม่ได้รับการให้สัญชาติไทย ได้รับการผ่อนผันให้อาศัยอยู่ในประเทศไทยได้ชั่วคราว'
    }
    return data_dict[citizen_id[0]]


def __born_address(citizen_id: str) -> str:
    # Extract born address from citizen id

    address_code = {
        '1001': 'เขตพระนคร',
        '1002': 'เขตดุสิต',
        '1003': 'เขตหนองจอก',
        '1004': 'เขตบางรัก',
        '1005': 'เขตบางเขน',
        '1006': 'เขตบางกะปิ',
        '1007': 'เขตปทุมวัน',
        '1008': 'เขตป้อมปราบศัตรูพ่าย',
        '1009': 'เขตพระโขนง',
        '1010': 'เขตมีนบุรี',
        '1011': 'เขตลาดกระบัง',
        '1012': 'เขตยานนาวา',
        '1013': 'เขตสัมพันธวงศ์',
        '1014': 'เขตพญาไท',
        '1015': 'เขตธนบุรี',
        '1016': 'เขตบางกอกใหญ่',
        '1017': 'เขตห้วยขวาง',
        '1018': 'เขตคลองสาน',
        '1019': 'เขตตลิ่งชัน',
        '1020': 'เขตบางกอกน้อย',
        '1021': 'เขตบางขุนเทียน',
        '1022': 'เขตภาษีเจริญ',
        '1023': 'เขตหนองแขม',
        '1024': 'เขตราษฎร์บูรณะ',
        '1025': 'เขตบางพลัด',
        '1026': 'เขตดินแดง',
        '1027': 'เขตบึงกุ่ม',
        '1028': 'เขตสาทร',
        '1029': 'เขตบางซื่อ',
        '1030': 'เขตจตุจักร',
        '1031': 'เขตบางคอแหลม',
        '1032': 'เขตประเวศ',
        '1033': 'เขตคลองเตย',
        '1034': 'เขตสวนหลวง',
        '1035': 'เขตจอมทอง',
        '1036': 'เขตดอนเมือง',
        '1037': 'เขตราชเทวี',
        '1038': 'เขตลาดพร้าว',
        '1039': 'เขตวัฒนา',
        '1040': 'เขตบางแค',
        '1041': 'เขตหลักสี่',
        '1042': 'เขตสายไหม',
        '1043': 'เขตคันนายาว',
        '1044': 'เขตสะพานสูง',
        '1045': 'เขตวังทองหลาง',
        '1046': 'เขตคลองสามวา',
        '1047': 'เขตบางนา',
        '1048': 'เขตทวีวัฒนา',
        '1049': 'เขตทุ่งครุ',
        '1050': 'เขตบางบอน',
        '1081': 'บ้านทะวาย*',
        '1099': 'สำนักทะเบียนกลาง*',
        '1101': 'เมืองสมุทรปราการ',
        '1102': 'บางบ่อ',
        '1103': 'บางพลี',
        '1104': 'พระประแดง',
        '1105': 'พระสมุทรเจดีย์',
        '1106': 'บางเสาธง',
        '1201': 'เมืองนนทบุรี',
        '1202': 'บางกรวย',
        '1203': 'บางใหญ่',
        '1204': 'บางบัวทอง',
        '1205': 'ไทรน้อย',
        '1206': 'ปากเกร็ด',
        '1251': 'เทศบาลนครนนทบุรี (สาขาแขวงท่าทราย)*',
        '1297': 'เทศบาลเมืองปากเกร็ด*',
        '1301': 'เมืองปทุมธานี',
        '1302': 'คลองหลวง',
        '1303': 'ธัญบุรี',
        '1304': 'หนองเสือ',
        '1305': 'ลาดหลุมแก้ว',
        '1306': 'ลำลูกกา',
        '1307': 'สามโคก',
        '1351': 'ลำลูกกา (สาขาตำบลคูคต)*',
        '1401': 'พระนครศรีอยุธยา',
        '1402': 'ท่าเรือ',
        '1403': 'นครหลวง',
        '1404': 'บางไทร',
        '1405': 'บางบาล',
        '1406': 'บางปะอิน',
        '1407': 'บางปะหัน',
        '1408': 'ผักไห่',
        '1409': 'ภาชี',
        '1410': 'ลาดบัวหลวง',
        '1411': 'วังน้อย',
        '1412': 'เสนา',
        '1413': 'บางซ้าย',
        '1414': 'อุทัย',
        '1415': 'มหาราช',
        '1416': 'บ้านแพรก',
        '1501': 'เมืองอ่างทอง',
        '1502': 'ไชโย',
        '1503': 'ป่าโมก',
        '1504': 'โพธิ์ทอง',
        '1505': 'แสวงหา',
        '1506': 'วิเศษชัยชาญ',
        '1507': 'สามโก้',
        '1601': 'เมืองลพบุรี',
        '1602': 'พัฒนานิคม',
        '1603': 'โคกสำโรง',
        '1604': 'ชัยบาดาล',
        '1605': 'ท่าวุ้ง',
        '1606': 'บ้านหมี่',
        '1607': 'ท่าหลวง',
        '1608': 'สระโบสถ์',
        '1609': 'โคกเจริญ',
        '1610': 'ลำสนธิ',
        '1611': 'หนองม่วง',
        '1681': 'อ.บ้านเช่า จ.ลพบุรี*',
        '1701': 'เมืองสิงห์บุรี',
        '1702': 'บางระจัน',
        '1703': 'ค่ายบางระจัน',
        '1704': 'พรหมบุรี',
        '1705': 'ท่าช้าง',
        '1706': 'อินทร์บุรี',
        '1801': 'เมืองชัยนาท',
        '1802': 'มโนรมย์',
        '1803': 'วัดสิงห์',
        '1804': 'สรรพยา',
        '1805': 'สรรคบุรี',
        '1806': 'หันคา',
        '1807': 'หนองมะโมง',
        '1808': 'เนินขาม',
        '1901': 'เมืองสระบุรี',
        '1902': 'แก่งคอย',
        '1903': 'หนองแค',
        '1904': 'วิหารแดง',
        '1905': 'หนองแซง',
        '1906': 'บ้านหมอ',
        '1907': 'ดอนพุด',
        '1908': 'หนองโดน',
        '1909': 'พระพุทธบาท',
        '1910': 'เสาไห้',
        '1911': 'มวกเหล็ก',
        '1912': 'วังม่วง',
        '1913': 'เฉลิมพระเกียรติ',
        '2001': 'เมืองชลบุรี',
        '2002': 'บ้านบึง',
        '2003': 'หนองใหญ่',
        '2004': 'บางละมุง',
        '2005': 'พานทอง',
        '2006': 'พนัสนิคม',
        '2007': 'ศรีราชา',
        '2008': 'เกาะสีชัง',
        '2009': 'สัตหีบ',
        '2010': 'บ่อทอง',
        '2011': 'เกาะจันทร์',
        '2051': 'สัตหีบ (สาขาตำบลบางเสร่)*',
        '2072': 'ท้องถิ่นเทศบาลเมืองหนองปรือ*',
        '2093': 'เทศบาลตำบลแหลมฉบัง*',
        '2099': 'เทศบาลเมืองชลบุรี*',
        '2101': 'เมืองระยอง',
        '2102': 'บ้านฉาง',
        '2103': 'แกลง',
        '2104': 'วังจันทร์',
        '2105': 'บ้านค่าย',
        '2106': 'ปลวกแดง',
        '2107': 'เขาชะเมา',
        '2108': 'นิคมพัฒนา',
        '2151': 'สาขาตำบลมาบข่า*',
        '2201': 'เมืองจันทบุรี',
        '2202': 'ขลุง',
        '2203': 'ท่าใหม่',
        '2204': 'โป่งน้ำร้อน',
        '2205': 'มะขาม',
        '2206': 'แหลมสิงห์',
        '2207': 'สอยดาว',
        '2208': 'แก่งหางแมว',
        '2209': 'นายายอาม',
        '2210': 'เขาคิชฌกูฏ',
        '2281': 'กิ่ง อ.กำพุธ จ.จันทบุรี*',
        '2301': 'เมืองตราด',
        '2302': 'คลองใหญ่',
        '2303': 'เขาสมิง',
        '2304': 'บ่อไร่',
        '2305': 'แหลมงอบ',
        '2306': 'เกาะกูด',
        '2307': 'เกาะช้าง',
        '2401': 'เมืองฉะเชิงเทรา',
        '2402': 'บางคล้า',
        '2403': 'บางน้ำเปรี้ยว',
        '2404': 'บางปะกง',
        '2405': 'บ้านโพธิ์',
        '2406': 'พนมสารคาม',
        '2407': 'ราชสาส์น',
        '2408': 'สนามชัยเขต',
        '2409': 'แปลงยาว',
        '2410': 'ท่าตะเกียบ',
        '2411': 'คลองเขื่อน',
        '2501': 'เมืองปราจีนบุรี',
        '2502': 'กบินทร์บุรี',
        '2503': 'นาดี',
        '2504': 'สระแก้ว*',
        '2505': 'วังน้ำเย็น*',
        '2506': 'บ้านสร้าง',
        '2507': 'ประจันตคาม',
        '2508': 'ศรีมหาโพธิ',
        '2509': 'ศรีมโหสถ',
        '2510': 'อรัญประเทศ*',
        '2511': 'ตาพระยา*',
        '2512': 'วัฒนานคร*',
        '2513': 'คลองหาด*',
        '2601': 'เมืองนครนายก',
        '2602': 'ปากพลี',
        '2603': 'บ้านนา',
        '2604': 'องครักษ์',
        '2701': 'เมืองสระแก้ว',
        '2702': 'คลองหาด',
        '2703': 'ตาพระยา',
        '2704': 'วังน้ำเย็น',
        '2705': 'วัฒนานคร',
        '2706': 'อรัญประเทศ',
        '2707': 'เขาฉกรรจ์',
        '2708': 'โคกสูง',
        '2709': 'วังสมบูรณ์',
        '3001': 'เมืองนครราชสีมา',
        '3002': 'ครบุรี',
        '3003': 'เสิงสาง',
        '3004': 'คง',
        '3005': 'บ้านเหลื่อม',
        '3006': 'จักราช',
        '3007': 'โชคชัย',
        '3008': 'ด่านขุนทด',
        '3009': 'โนนไทย',
        '3010': 'โนนสูง',
        '3011': 'ขามสะแกแสง',
        '3012': 'บัวใหญ่',
        '3013': 'ประทาย',
        '3014': 'ปักธงชัย',
        '3015': 'พิมาย',
        '3016': 'ห้วยแถลง',
        '3017': 'ชุมพวง',
        '3018': 'สูงเนิน',
        '3019': 'ขามทะเลสอ',
        '3020': 'สีคิ้ว',
        '3021': 'ปากช่อง',
        '3022': 'หนองบุญมาก',
        '3023': 'แก้งสนามนาง',
        '3024': 'โนนแดง',
        '3025': 'วังน้ำเขียว',
        '3026': 'เทพารักษ์',
        '3027': 'เมืองยาง',
        '3028': 'พระทองคำ',
        '3029': 'ลำทะเมนชัย',
        '3030': 'บัวลาย',
        '3031': 'สีดา',
        '3032': 'เฉลิมพระเกียรติ',
        '3049': 'ท้องถิ่นเทศบาลตำบลโพธิ์กลาง*',
        '3051': 'สาขาตำบลมะค่า-พลสงคราม*',
        '3081': 'โนนลาว*',
        '3101': 'เมืองบุรีรัมย์',
        '3102': 'คูเมือง',
        '3103': 'กระสัง',
        '3104': 'นางรอง',
        '3105': 'หนองกี่',
        '3106': 'ละหานทราย',
        '3107': 'ประโคนชัย',
        '3108': 'บ้านกรวด',
        '3109': 'พุทไธสง',
        '3110': 'ลำปลายมาศ',
        '3111': 'สตึก',
        '3112': 'ปะคำ',
        '3113': 'นาโพธิ์',
        '3114': 'หนองหงส์',
        '3115': 'พลับพลาชัย',
        '3116': 'ห้วยราช',
        '3117': 'โนนสุวรรณ',
        '3118': 'ชำนิ',
        '3119': 'บ้านใหม่ไชยพจน์',
        '3120': 'โนนดินแดง',
        '3121': 'บ้านด่าน',
        '3122': 'แคนดง',
        '3123': 'เฉลิมพระเกียรติ',
        '3201': 'เมืองสุรินทร์',
        '3202': 'ชุมพลบุรี',
        '3203': 'ท่าตูม',
        '3204': 'จอมพระ',
        '3205': 'ปราสาท',
        '3206': 'กาบเชิง',
        '3207': 'รัตนบุรี',
        '3208': 'สนม',
        '3209': 'ศีขรภูมิ',
        '3210': 'สังขะ',
        '3211': 'ลำดวน',
        '3212': 'สำโรงทาบ',
        '3213': 'บัวเชด',
        '3214': 'พนมดงรัก',
        '3215': 'ศรีณรงค์',
        '3216': 'เขวาสินรินทร์',
        '3217': 'โนนนารายณ์',
        '3301': 'เมืองศรีสะเกษ',
        '3302': 'ยางชุมน้อย',
        '3303': 'กันทรารมย์',
        '3304': 'กันทรลักษ์',
        '3305': 'ขุขันธ์',
        '3306': 'ไพรบึง',
        '3307': 'ปรางค์กู่',
        '3308': 'ขุนหาญ',
        '3309': 'ราษีไศล',
        '3310': 'อุทุมพรพิสัย',
        '3311': 'บึงบูรพ์',
        '3312': 'ห้วยทับทัน',
        '3313': 'โนนคูณ',
        '3314': 'ศรีรัตนะ',
        '3315': 'น้ำเกลี้ยง',
        '3316': 'วังหิน',
        '3317': 'ภูสิงห์',
        '3318': 'เมืองจันทร์',
        '3319': 'เบญจลักษ์',
        '3320': 'พยุห์',
        '3321': 'โพธิ์ศรีสุวรรณ',
        '3322': 'ศิลาลาด',
        '3401': 'เมืองอุบลราชธานี',
        '3402': 'ศรีเมืองใหม่',
        '3403': 'โขงเจียม',
        '3404': 'เขื่องใน',
        '3405': 'เขมราฐ',
        '3406': 'ชานุมาน*',
        '3407': 'เดชอุดม',
        '3408': 'นาจะหลวย',
        '3409': 'น้ำยืน',
        '3410': 'บุณฑริก',
        '3411': 'ตระการพืชผล',
        '3412': 'กุดข้าวปุ้น',
        '3413': 'พนา*',
        '3414': 'ม่วงสามสิบ',
        '3415': 'วารินชำราบ',
        '3416': 'อำนาจเจริญ*',
        '3417': 'เสนางคนิคม*',
        '3418': 'หัวตะพาน*',
        '3419': 'พิบูลมังสาหาร',
        '3420': 'ตาลสุม',
        '3421': 'โพธิ์ไทร',
        '3422': 'สำโรง',
        '3423': 'กิ่งอำเภอลืออำนาจ*',
        '3424': 'ดอนมดแดง',
        '3425': 'สิรินธร',
        '3426': 'ทุ่งศรีอุดม',
        '3427': 'ปทุมราชวงศา*',
        '3428': 'กิ่งอำเภอศรีหลักชัย*',
        '3429': 'นาเยีย',
        '3430': 'นาตาล',
        '3431': 'เหล่าเสือโก้ก',
        '3432': 'สว่างวีระวงศ์',
        '3433': 'น้ำขุ่น',
        '3481': 'อ.สุวรรณวารี จ.อุบลราชธานี*',
        '3501': 'เมืองยโสธร',
        '3502': 'ทรายมูล',
        '3503': 'กุดชุม',
        '3504': 'คำเขื่อนแก้ว',
        '3505': 'ป่าติ้ว',
        '3506': 'มหาชนะชัย',
        '3507': 'ค้อวัง',
        '3508': 'เลิงนกทา',
        '3509': 'ไทยเจริญ',
        '3601': 'เมืองชัยภูมิ',
        '3602': 'บ้านเขว้า',
        '3603': 'คอนสวรรค์',
        '3604': 'เกษตรสมบูรณ์',
        '3605': 'หนองบัวแดง',
        '3606': 'จัตุรัส',
        '3607': 'บำเหน็จณรงค์',
        '3608': 'หนองบัวระเหว',
        '3609': 'เทพสถิต',
        '3610': 'ภูเขียว',
        '3611': 'บ้านแท่น',
        '3612': 'แก้งคร้อ',
        '3613': 'คอนสาร',
        '3614': 'ภักดีชุมพล',
        '3615': 'เนินสง่า',
        '3616': 'ซับใหญ่',
        '3651': 'เมืองชัยภูมิ (สาขาตำบลโนนสำราญ)*',
        '3652': 'สาขาตำบลบ้านหว่าเฒ่า*',
        '3653': 'หนองบัวแดง (สาขาตำบลวังชมภู)*',
        '3654': 'กิ่งอำเภอซับใหญ่ (สาขาตำบลซับใหญ่)*',
        '3655': 'สาขาตำบลโคกเพชร*',
        '3656': 'เทพสถิต (สาขาตำบลนายางกลัก)*',
        '3657': 'บ้านแท่น (สาขาตำบลบ้านเต่า)*',
        '3658': 'แก้งคร้อ (สาขาตำบลท่ามะไฟหวาน)*',
        '3659': 'คอนสาร (สาขาตำบลโนนคูณ)*',
        '3701': 'เมืองอำนาจเจริญ',
        '3702': 'ชานุมาน',
        '3703': 'ปทุมราชวงศา',
        '3704': 'พนา',
        '3705': 'เสนางคนิคม',
        '3706': 'หัวตะพาน',
        '3707': 'ลืออำนาจ',
        '3801': 'เมืองบึงกาฬ',
        '3802': 'พรเจริญ',
        '3803': 'โซ่พิสัย',
        '3804': 'เซกา',
        '3805': 'ปากคาด',
        '3806': 'บึงโขงหลง',
        '3807': 'ศรีวิไล',
        '3808': 'บุ่งคล้า',
        '3901': 'เมืองหนองบัวลำภู',
        '3902': 'นากลาง',
        '3903': 'โนนสัง',
        '3904': 'ศรีบุญเรือง',
        '3905': 'สุวรรณคูหา',
        '3906': 'นาวัง',
        '4001': 'เมืองขอนแก่น',
        '4002': 'บ้านฝาง',
        '4003': 'พระยืน',
        '4004': 'หนองเรือ',
        '4005': 'ชุมแพ',
        '4006': 'สีชมพู',
        '4007': 'น้ำพอง',
        '4008': 'อุบลรัตน์',
        '4009': 'กระนวน',
        '4010': 'บ้านไผ่',
        '4011': 'เปือยน้อย',
        '4012': 'พล',
        '4013': 'แวงใหญ่',
        '4014': 'แวงน้อย',
        '4015': 'หนองสองห้อง',
        '4016': 'ภูเวียง',
        '4017': 'มัญจาคีรี',
        '4018': 'ชนบท',
        '4019': 'เขาสวนกวาง',
        '4020': 'ภูผาม่าน',
        '4021': 'ซำสูง',
        '4022': 'โคกโพธิ์ไชย',
        '4023': 'หนองนาคำ',
        '4024': 'บ้านแฮด',
        '4025': 'โนนศิลา',
        '4029': 'เวียงเก่า',
        '4068': 'ท้องถิ่นเทศบาลตำบลบ้านเป็ด*',
        '4098': 'เทศบาลตำบลเมืองพล*',
        '4101': 'เมืองอุดรธานี',
        '4102': 'กุดจับ',
        '4103': 'หนองวัวซอ',
        '4104': 'กุมภวาปี',
        '4105': 'โนนสะอาด',
        '4106': 'หนองหาน',
        '4107': 'ทุ่งฝน',
        '4108': 'ไชยวาน',
        '4109': 'ศรีธาตุ',
        '4110': 'วังสามหมอ',
        '4111': 'บ้านดุง',
        '4112': 'หนองบัวลำภู*',
        '4113': 'ศรีบุญเรือง*',
        '4114': 'นากลาง*',
        '4115': 'สุวรรณคูหา*',
        '4116': 'โนนสัง*',
        '4117': 'บ้านผือ',
        '4118': 'น้ำโสม',
        '4119': 'เพ็ญ',
        '4120': 'สร้างคอม',
        '4121': 'หนองแสง',
        '4122': 'นายูง',
        '4123': 'พิบูลย์รักษ์',
        '4124': 'กู่แก้ว',
        '4125': 'ประจักษ์ศิลปาคม',
        '4201': 'เมืองเลย',
        '4202': 'นาด้วง',
        '4203': 'เชียงคาน',
        '4204': 'ปากชม',
        '4205': 'ด่านซ้าย',
        '4206': 'นาแห้ว',
        '4207': 'ภูเรือ',
        '4208': 'ท่าลี่',
        '4209': 'วังสะพุง',
        '4210': 'ภูกระดึง',
        '4211': 'ภูหลวง',
        '4212': 'ผาขาว',
        '4213': 'เอราวัณ',
        '4214': 'หนองหิน',
        '4301': 'เมืองหนองคาย',
        '4302': 'ท่าบ่อ',
        '4303': 'บึงกาฬ*',
        '4304': 'พรเจริญ*',
        '4305': 'โพนพิสัย',
        '4306': 'โซ่พิสัย*',
        '4307': 'ศรีเชียงใหม่',
        '4308': 'สังคม',
        '4309': 'เซกา*',
        '4310': 'ปากคาด*',
        '4311': 'บึงโขงหลง*',
        '4312': 'ศรีวิไล*',
        '4313': 'บุ่งคล้า*',
        '4314': 'สระใคร',
        '4315': 'เฝ้าไร่',
        '4316': 'รัตนวาปี',
        '4317': 'โพธิ์ตาก',
        '4401': 'เมืองมหาสารคาม',
        '4402': 'แกดำ',
        '4403': 'โกสุมพิสัย',
        '4404': 'กันทรวิชัย',
        '4405': 'เชียงยืน',
        '4406': 'บรบือ',
        '4407': 'นาเชือก',
        '4408': 'พยัคฆภูมิพิสัย',
        '4409': 'วาปีปทุม',
        '4410': 'นาดูน',
        '4411': 'ยางสีสุราช',
        '4412': 'กุดรัง',
        '4413': 'ชื่นชม',
        '4481': 'หลุบ*',
        '4501': 'เมืองร้อยเอ็ด',
        '4502': 'เกษตรวิสัย',
        '4503': 'ปทุมรัตต์',
        '4504': 'จตุรพักตรพิมาน',
        '4505': 'ธวัชบุรี',
        '4506': 'พนมไพร',
        '4507': 'โพนทอง',
        '4508': 'โพธิ์ชัย',
        '4509': 'หนองพอก',
        '4510': 'เสลภูมิ',
        '4511': 'สุวรรณภูมิ',
        '4512': 'เมืองสรวง',
        '4513': 'โพนทราย',
        '4514': 'อาจสามารถ',
        '4515': 'เมยวดี',
        '4516': 'ศรีสมเด็จ',
        '4517': 'จังหาร',
        '4518': 'เชียงขวัญ',
        '4519': 'หนองฮี',
        '4520': 'ทุ่งเขาหลวง',
        '4601': 'เมืองกาฬสินธุ์',
        '4602': 'นามน',
        '4603': 'กมลาไสย',
        '4604': 'ร่องคำ',
        '4605': 'กุฉินารายณ์',
        '4606': 'เขาวง',
        '4607': 'ยางตลาด',
        '4608': 'ห้วยเม็ก',
        '4609': 'สหัสขันธ์',
        '4610': 'คำม่วง',
        '4611': 'ท่าคันโท',
        '4612': 'หนองกุงศรี',
        '4613': 'สมเด็จ',
        '4614': 'ห้วยผึ้ง',
        '4615': 'สามชัย',
        '4616': 'นาคู',
        '4617': 'ดอนจาน',
        '4618': 'ฆ้องชัย',
        '4701': 'เมืองสกลนคร',
        '4702': 'กุสุมาลย์',
        '4703': 'กุดบาก',
        '4704': 'พรรณานิคม',
        '4705': 'พังโคน',
        '4706': 'วาริชภูมิ',
        '4707': 'นิคมน้ำอูน',
        '4708': 'วานรนิวาส',
        '4709': 'คำตากล้า',
        '4710': 'บ้านม่วง',
        '4711': 'อากาศอำนวย',
        '4712': 'สว่างแดนดิน',
        '4713': 'ส่องดาว',
        '4714': 'เต่างอย',
        '4715': 'โคกศรีสุพรรณ',
        '4716': 'เจริญศิลป์',
        '4717': 'โพนนาแก้ว',
        '4718': 'ภูพาน',
        '4751': 'วานรนิวาส (สาขาตำบลกุดเรือคำ)*',
        '4781': 'อ.บ้านหัน จ.สกลนคร*',
        '4801': 'เมืองนครพนม',
        '4802': 'ปลาปาก',
        '4803': 'ท่าอุเทน',
        '4804': 'บ้านแพง',
        '4805': 'ธาตุพนม',
        '4806': 'เรณูนคร',
        '4807': 'นาแก',
        '4808': 'ศรีสงคราม',
        '4809': 'นาหว้า',
        '4810': 'โพนสวรรค์',
        '4811': 'นาทม',
        '4812': 'วังยาง',
        '4901': 'เมืองมุกดาหาร',
        '4902': 'นิคมคำสร้อย',
        '4903': 'ดอนตาล',
        '4904': 'ดงหลวง',
        '4905': 'คำชะอี',
        '4906': 'หว้านใหญ่',
        '4907': 'หนองสูง',
        '5001': 'เมืองเชียงใหม่',
        '5002': 'จอมทอง',
        '5003': 'แม่แจ่ม',
        '5004': 'เชียงดาว',
        '5005': 'ดอยสะเก็ด',
        '5006': 'แม่แตง',
        '5007': 'แม่ริม',
        '5008': 'สะเมิง',
        '5009': 'ฝาง',
        '5010': 'แม่อาย',
        '5011': 'พร้าว',
        '5012': 'สันป่าตอง',
        '5013': 'สันกำแพง',
        '5014': 'สันทราย',
        '5015': 'หางดง',
        '5016': 'ฮอด',
        '5017': 'ดอยเต่า',
        '5018': 'อมก๋อย',
        '5019': 'สารภี',
        '5020': 'เวียงแหง',
        '5021': 'ไชยปราการ',
        '5022': 'แม่วาง',
        '5023': 'แม่ออน',
        '5024': 'ดอยหล่อ',
        '5025': 'กัลยาณิวัฒนา',
        '5051': 'เทศบาลนครเชียงใหม่ (สาขาแขวงกาลวิละ*',
        '5052': 'เทศบาลนครเชียงใหม่ (สาขาแขวงศรีวิชั*',
        '5053': 'เทศบาลนครเชียงใหม่ (สาขาเม็งราย*',
        '5101': 'เมืองลำพูน',
        '5102': 'แม่ทา',
        '5103': 'บ้านโฮ่ง',
        '5104': 'ลี้',
        '5105': 'ทุ่งหัวช้าง',
        '5106': 'ป่าซาง',
        '5107': 'บ้านธิ',
        '5108': 'เวียงหนองล่อง',
        '5201': 'เมืองลำปาง',
        '5202': 'แม่เมาะ',
        '5203': 'เกาะคา',
        '5204': 'เสริมงาม',
        '5205': 'งาว',
        '5206': 'แจ้ห่ม',
        '5207': 'วังเหนือ',
        '5208': 'เถิน',
        '5209': 'แม่พริก',
        '5210': 'แม่ทะ',
        '5211': 'สบปราบ',
        '5212': 'ห้างฉัตร',
        '5213': 'เมืองปาน',
        '5301': 'เมืองอุตรดิตถ์',
        '5302': 'ตรอน',
        '5303': 'ท่าปลา',
        '5304': 'น้ำปาด',
        '5305': 'ฟากท่า',
        '5306': 'บ้านโคก',
        '5307': 'พิชัย',
        '5308': 'ลับแล',
        '5309': 'ทองแสนขัน',
        '5401': 'เมืองแพร่',
        '5402': 'ร้องกวาง',
        '5403': 'ลอง',
        '5404': 'สูงเม่น',
        '5405': 'เด่นชัย',
        '5406': 'สอง',
        '5407': 'วังชิ้น',
        '5408': 'หนองม่วงไข่',
        '5501': 'เมืองน่าน',
        '5502': 'แม่จริม',
        '5503': 'บ้านหลวง',
        '5504': 'นาน้อย',
        '5505': 'ปัว',
        '5506': 'ท่าวังผา',
        '5507': 'เวียงสา',
        '5508': 'ทุ่งช้าง',
        '5509': 'เชียงกลาง',
        '5510': 'นาหมื่น',
        '5511': 'สันติสุข',
        '5512': 'บ่อเกลือ',
        '5513': 'สองแคว',
        '5514': 'ภูเพียง',
        '5515': 'เฉลิมพระเกียรติ',
        '5601': 'เมืองพะเยา',
        '5602': 'จุน',
        '5603': 'เชียงคำ',
        '5604': 'เชียงม่วน',
        '5605': 'ดอกคำใต้',
        '5606': 'ปง',
        '5607': 'แม่ใจ',
        '5608': 'ภูซาง',
        '5609': 'ภูกามยาว',
        '5701': 'เมืองเชียงราย',
        '5702': 'เวียงชัย',
        '5703': 'เชียงของ',
        '5704': 'เทิง',
        '5705': 'พาน',
        '5706': 'ป่าแดด',
        '5707': 'แม่จัน',
        '5708': 'เชียงแสน',
        '5709': 'แม่สาย',
        '5710': 'แม่สรวย',
        '5711': 'เวียงป่าเป้า',
        '5712': 'พญาเม็งราย',
        '5713': 'เวียงแก่น',
        '5714': 'ขุนตาล',
        '5715': 'แม่ฟ้าหลวง',
        '5716': 'แม่ลาว',
        '5717': 'เวียงเชียงรุ้ง',
        '5718': 'ดอยหลวง',
        '5801': 'เมืองแม่ฮ่องสอน',
        '5802': 'ขุนยวม',
        '5803': 'ปาย',
        '5804': 'แม่สะเรียง',
        '5805': 'แม่ลาน้อย',
        '5806': 'สบเมย',
        '5807': 'ปางมะผ้า',
        '5881': 'อ.ม่วยต่อ จ.แม่ฮ่องสอน*',
        '6001': 'เมืองนครสวรรค์',
        '6002': 'โกรกพระ',
        '6003': 'ชุมแสง',
        '6004': 'หนองบัว',
        '6005': 'บรรพตพิสัย',
        '6006': 'เก้าเลี้ยว',
        '6007': 'ตาคลี',
        '6008': 'ท่าตะโก',
        '6009': 'ไพศาลี',
        '6010': 'พยุหะคีรี',
        '6011': 'ลาดยาว',
        '6012': 'ตากฟ้า',
        '6013': 'แม่วงก์',
        '6014': 'แม่เปิน',
        '6015': 'ชุมตาบง',
        '6051': 'สาขาตำบลห้วยน้ำหอม*',
        '6052': 'กิ่งอำเภอชุมตาบง (สาขาตำบลชุมตาบง)*',
        '6053': 'แม่วงก์ (สาขาตำบลแม่เล่ย์)*',
        '6101': 'เมืองอุทัยธานี',
        '6102': 'ทัพทัน',
        '6103': 'สว่างอารมณ์',
        '6104': 'หนองฉาง',
        '6105': 'หนองขาหย่าง',
        '6106': 'บ้านไร่',
        '6107': 'ลานสัก',
        '6108': 'ห้วยคต',
        '6201': 'เมืองกำแพงเพชร',
        '6202': 'ไทรงาม',
        '6203': 'คลองลาน',
        '6204': 'ขาณุวรลักษบุรี',
        '6205': 'คลองขลุง',
        '6206': 'พรานกระต่าย',
        '6207': 'ลานกระบือ',
        '6208': 'ทรายทองวัฒนา',
        '6209': 'ปางศิลาทอง',
        '6210': 'บึงสามัคคี',
        '6211': 'โกสัมพีนคร',
        '6301': 'เมืองตาก',
        '6302': 'บ้านตาก',
        '6303': 'สามเงา',
        '6304': 'แม่ระมาด',
        '6305': 'ท่าสองยาง',
        '6306': 'แม่สอด',
        '6307': 'พบพระ',
        '6308': 'อุ้มผาง',
        '6309': 'วังเจ้า',
        '6381': 'กิ่ง อ.ท่าปุย จ.ตาก*',
        '6401': 'เมืองสุโขทัย',
        '6402': 'บ้านด่านลานหอย',
        '6403': 'คีรีมาศ',
        '6404': 'กงไกรลาศ',
        '6405': 'ศรีสัชนาลัย',
        '6406': 'ศรีสำโรง',
        '6407': 'สวรรคโลก',
        '6408': 'ศรีนคร',
        '6409': 'ทุ่งเสลี่ยม',
        '6501': 'เมืองพิษณุโลก',
        '6502': 'นครไทย',
        '6503': 'ชาติตระการ',
        '6504': 'บางระกำ',
        '6505': 'บางกระทุ่ม',
        '6506': 'พรหมพิราม',
        '6507': 'วัดโบสถ์',
        '6508': 'วังทอง',
        '6509': 'เนินมะปราง',
        '6601': 'เมืองพิจิตร',
        '6602': 'วังทรายพูน',
        '6603': 'โพธิ์ประทับช้าง',
        '6604': 'ตะพานหิน',
        '6605': 'บางมูลนาก',
        '6606': 'โพทะเล',
        '6607': 'สามง่าม',
        '6608': 'ทับคล้อ',
        '6609': 'สากเหล็ก',
        '6610': 'บึงนาราง',
        '6611': 'ดงเจริญ',
        '6612': 'วชิรบารมี',
        '6701': 'เมืองเพชรบูรณ์',
        '6702': 'ชนแดน',
        '6703': 'หล่มสัก',
        '6704': 'หล่มเก่า',
        '6705': 'วิเชียรบุรี',
        '6706': 'ศรีเทพ',
        '6707': 'หนองไผ่',
        '6708': 'บึงสามพัน',
        '6709': 'น้ำหนาว',
        '6710': 'วังโป่ง',
        '6711': 'เขาค้อ',
        '7001': 'เมืองราชบุรี',
        '7002': 'จอมบึง',
        '7003': 'สวนผึ้ง',
        '7004': 'ดำเนินสะดวก',
        '7005': 'บ้านโป่ง',
        '7006': 'บางแพ',
        '7007': 'โพธาราม',
        '7008': 'ปากท่อ',
        '7009': 'วัดเพลง',
        '7010': 'บ้านคา',
        '7074': 'ท้องถิ่นเทศบาลตำบลบ้านฆ้อง*',
        '7101': 'เมืองกาญจนบุรี',
        '7102': 'ไทรโยค',
        '7103': 'บ่อพลอย',
        '7104': 'ศรีสวัสดิ์',
        '7105': 'ท่ามะกา',
        '7106': 'ท่าม่วง',
        '7107': 'ทองผาภูมิ',
        '7108': 'สังขละบุรี',
        '7109': 'พนมทวน',
        '7110': 'เลาขวัญ',
        '7111': 'ด่านมะขามเตี้ย',
        '7112': 'หนองปรือ',
        '7113': 'ห้วยกระเจา',
        '7151': 'สาขาตำบลท่ากระดาน*',
        '7181': 'บ้านทวน จ.กาญจนบุรี*',
        '7201': 'เมืองสุพรรณบุรี',
        '7202': 'เดิมบางนางบวช',
        '7203': 'ด่านช้าง',
        '7204': 'บางปลาม้า',
        '7205': 'ศรีประจันต์',
        '7206': 'ดอนเจดีย์',
        '7207': 'สองพี่น้อง',
        '7208': 'สามชุก',
        '7209': 'อู่ทอง',
        '7210': 'หนองหญ้าไซ',
        '7301': 'เมืองนครปฐม',
        '7302': 'กำแพงแสน',
        '7303': 'นครชัยศรี',
        '7304': 'ดอนตูม',
        '7305': 'บางเลน',
        '7306': 'สามพราน',
        '7307': 'พุทธมณฑล',
        '7401': 'เมืองสมุทรสาคร',
        '7402': 'กระทุ่มแบน',
        '7403': 'บ้านแพ้ว',
        '7501': 'เมืองสมุทรสงคราม',
        '7502': 'บางคนที',
        '7503': 'อัมพวา',
        '7601': 'เมืองเพชรบุรี',
        '7602': 'เขาย้อย',
        '7603': 'หนองหญ้าปล้อง',
        '7604': 'ชะอำ',
        '7605': 'ท่ายาง',
        '7606': 'บ้านลาด',
        '7607': 'บ้านแหลม',
        '7608': 'แก่งกระจาน',
        '7701': 'เมืองประจวบคีรีขันธ์',
        '7702': 'กุยบุรี',
        '7703': 'ทับสะแก',
        '7704': 'บางสะพาน',
        '7705': 'บางสะพานน้อย',
        '7706': 'ปราณบุรี',
        '7707': 'หัวหิน',
        '7708': 'สามร้อยยอด',
        '8001': 'เมืองนครศรีธรรมราช',
        '8002': 'พรหมคีรี',
        '8003': 'ลานสกา',
        '8004': 'ฉวาง',
        '8005': 'พิปูน',
        '8006': 'เชียรใหญ่',
        '8007': 'ชะอวด',
        '8008': 'ท่าศาลา',
        '8009': 'ทุ่งสง',
        '8010': 'นาบอน',
        '8011': 'ทุ่งใหญ่',
        '8012': 'ปากพนัง',
        '8013': 'ร่อนพิบูลย์',
        '8014': 'สิชล',
        '8015': 'ขนอม',
        '8016': 'หัวไทร',
        '8017': 'บางขัน',
        '8018': 'ถ้ำพรรณรา',
        '8019': 'จุฬาภรณ์',
        '8020': 'พระพรหม',
        '8021': 'นบพิตำ',
        '8022': 'ช้างกลาง',
        '8023': 'เฉลิมพระเกียรติ',
        '8051': 'เชียรใหญ่ (สาขาตำบลเสือหึง)*',
        '8052': 'สาขาตำบลสวนหลวง*',
        '8053': 'ร่อนพิบูลย์ (สาขาตำบลหินตก)*',
        '8054': 'หัวไทร (สาขาตำบลควนชะลิก)*',
        '8055': 'ทุ่งสง (สาขาตำบลกะปาง)*',
        '8101': 'เมืองกระบี่',
        '8102': 'เขาพนม',
        '8103': 'เกาะลันตา',
        '8104': 'คลองท่อม',
        '8105': 'อ่าวลึก',
        '8106': 'ปลายพระยา',
        '8107': 'ลำทับ',
        '8108': 'เหนือคลอง',
        '8201': 'เมืองพังงา',
        '8202': 'เกาะยาว',
        '8203': 'กะปง',
        '8204': 'ตะกั่วทุ่ง',
        '8205': 'ตะกั่วป่า',
        '8206': 'คุระบุรี',
        '8207': 'ทับปุด',
        '8208': 'ท้ายเหมือง',
        '8301': 'เมืองภูเก็ต',
        '8302': 'กะทู้',
        '8303': 'ถลาง',
        '8381': 'ทุ่งคา*',
        '8401': 'เมืองสุราษฎร์ธานี',
        '8402': 'กาญจนดิษฐ์',
        '8403': 'ดอนสัก',
        '8404': 'เกาะสมุย',
        '8405': 'เกาะพะงัน',
        '8406': 'ไชยา',
        '8407': 'ท่าชนะ',
        '8408': 'คีรีรัฐนิคม',
        '8409': 'บ้านตาขุน',
        '8410': 'พนม',
        '8411': 'ท่าฉาง',
        '8412': 'บ้านนาสาร',
        '8413': 'บ้านนาเดิม',
        '8414': 'เคียนซา',
        '8415': 'เวียงสระ',
        '8416': 'พระแสง',
        '8417': 'พุนพิน',
        '8418': 'ชัยบุรี',
        '8419': 'วิภาวดี',
        '8451': 'เกาะพงัน (สาขาตำบลเกาะเต่า)*',
        '8481': 'อ.บ้านดอน จ.สุราษฎร์ธานี*',
        '8501': 'เมืองระนอง',
        '8502': 'ละอุ่น',
        '8503': 'กะเปอร์',
        '8504': 'กระบุรี',
        '8505': 'สุขสำราญ',
        '8601': 'เมืองชุมพร',
        '8602': 'ท่าแซะ',
        '8603': 'ปะทิว',
        '8604': 'หลังสวน',
        '8605': 'ละแม',
        '8606': 'พะโต๊ะ',
        '8607': 'สวี',
        '8608': 'ทุ่งตะโก',
        '9001': 'เมืองสงขลา',
        '9002': 'สทิงพระ',
        '9003': 'จะนะ',
        '9004': 'นาทวี',
        '9005': 'เทพา',
        '9006': 'สะบ้าย้อย',
        '9007': 'ระโนด',
        '9008': 'กระแสสินธุ์',
        '9009': 'รัตภูมิ',
        '9010': 'สะเดา',
        '9011': 'หาดใหญ่',
        '9012': 'นาหม่อม',
        '9013': 'ควนเนียง',
        '9014': 'บางกล่ำ',
        '9015': 'สิงหนคร',
        '9016': 'คลองหอยโข่ง',
        '9077': 'ท้องถิ่นเทศบาลตำบลสำนักขาม*',
        '9096': 'เทศบาลตำบลบ้านพรุ*',
        '9101': 'เมืองสตูล',
        '9102': 'ควนโดน',
        '9103': 'ควนกาหลง',
        '9104': 'ท่าแพ',
        '9105': 'ละงู',
        '9106': 'ทุ่งหว้า',
        '9107': 'มะนัง',
        '9201': 'เมืองตรัง',
        '9202': 'กันตัง',
        '9203': 'ย่านตาขาว',
        '9204': 'ปะเหลียน',
        '9205': 'สิเกา',
        '9206': 'ห้วยยอด',
        '9207': 'วังวิเศษ',
        '9208': 'นาโยง',
        '9209': 'รัษฎา',
        '9210': 'หาดสำราญ',
        '9251': 'อำเภอเมืองตรัง(สาขาคลองเต็ง)*',
        '9301': 'เมืองพัทลุง',
        '9302': 'กงหรา',
        '9303': 'เขาชัยสน',
        '9304': 'ตะโหมด',
        '9305': 'ควนขนุน',
        '9306': 'ปากพะยูน',
        '9307': 'ศรีบรรพต',
        '9308': 'ป่าบอน',
        '9309': 'บางแก้ว',
        '9310': 'ป่าพะยอม',
        '9311': 'ศรีนครินทร์',
        '9401': 'เมืองปัตตานี',
        '9402': 'โคกโพธิ์',
        '9403': 'หนองจิก',
        '9404': 'ปะนาเระ',
        '9405': 'มายอ',
        '9406': 'ทุ่งยางแดง',
        '9407': 'สายบุรี',
        '9408': 'ไม้แก่น',
        '9409': 'ยะหริ่ง',
        '9410': 'ยะรัง',
        '9411': 'กะพ้อ',
        '9412': 'แม่ลาน',
        '9501': 'เมืองยะลา',
        '9502': 'เบตง',
        '9503': 'บันนังสตา',
        '9504': 'ธารโต',
        '9505': 'ยะหา',
        '9506': 'รามัน',
        '9507': 'กาบัง',
        '9508': 'กรงปินัง',
        '9601': 'เมืองนราธิวาส',
        '9602': 'ตากใบ',
        '9603': 'บาเจาะ',
        '9604': 'ยี่งอ',
        '9605': 'ระแงะ',
        '9606': 'รือเสาะ',
        '9607': 'ศรีสาคร',
        '9608': 'แว้ง',
        '9609': 'สุคิริน',
        '9610': 'สุไหงโก-ลก',
        '9611': 'สุไหงปาดี',
        '9612': 'จะแนะ',
        '9613': 'เจาะไอร้อง',
        '9681': 'อ.บางนรา จ.นราธิวาส*',
    }

    try:
        return address_code[citizen_id[1:5]]
    except KeyError:
        return 'Not found'


def __first_order(citizen_id: str) -> int:
    # Extract first order from citizen id
    return int(citizen_id[5:10])


def __second_order(citizen_id: str) -> int:
    # Extract second order from citizen id
    return int(citizen_id[10:12])
